@@ -12,7 +12,7 @@ accumulate.data <- function(enadata) {
 
   conversations.by <- enadata$get("conversations.by")
   window <- enadata$get("window.size")
-  binaryStanzas <- F
+  # binaryStanzas <- F
   units.exclude <- enadata$get("units.exclude")
 
   if(is.null(trajectory.by)) {
@@ -136,13 +136,13 @@ accumulate.data <- function(enadata) {
     #                          ];
     #
     # } else {
+            # ,binaryStanzas = binaryStanzas
       dfDT.co.occurrences <- dfDT_codes[,
           (codedTriNames) := ref_window_df(
             .SD[, .SD, .SDcols = just_codes],
             windowSize = window$back,
             windowForward = window$forward,
-            binary = binary,
-            binaryStanzas = binaryStanzas
+            binary = binary
           ),
           by = conversations.by,
           .SDcols = initial_cols,
